==> kubernetes-model-1.0.40-sources.jar: io/fabric8/openshift/api/model/DeploymentTriggerImageChangeParamsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.List;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DeploymentTriggerImageChangeParamsFluentImpl<T extends DeploymentTriggerImageChangeParamsFluent<T>> extends BaseFluent<T> implements DeploymentTriggerImageChangeParamsFluent<T>{

     Boolean automatic;     List<String> containerNames = new ArrayList();     VisitableBuilder<ObjectReference, ?> from;     String lastTriggeredImage;     Map<String, Object> additionalProperties = new HashMap();
public DeploymentTriggerImageChangeParamsFluentImpl(){
    
}
public DeploymentTriggerImageChangeParamsFluentImpl( DeploymentTriggerImageChangeParams instance ){
    this.withAutomatic(instance.getAutomatic()); this.withContainerNames(instance.getContainerNames()); this.withFrom(instance.getFrom()); this.withLastTriggeredImage(instance.getLastTriggeredImage()); 
}

    public Boolean isAutomatic(){
    return this.automatic;
    }
    public T withAutomatic( Boolean automatic){
    this.automatic=automatic; return (T) this;
    }
    public T addToContainerNames( String ...items){
    for (String item : items) {this.containerNames.add(item);} return (T)this;
    }
    public T removeFromContainerNames( String ...items){
    for (String item : items) {this.containerNames.remove(item);} return (T)this;
    }
    public List<String> getContainerNames(){
    return this.containerNames;
    }
    public T withContainerNames( List<String> containerNames){
    this.containerNames.clear();if (containerNames != null) {for (String item : containerNames){this.addToContainerNames(item);}} return (T) this;
    }
    public T withContainerNames( String ...containerNames){
    this.containerNames.clear(); if (containerNames != null) {for (String item :containerNames){ this.addToContainerNames(item);}} return (T) this;
    }
    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNestedImpl<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNestedImpl<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public String getLastTriggeredImage(){
    return this.lastTriggeredImage;
    }
    public T withLastTriggeredImage( String lastTriggeredImage){
    this.lastTriggeredImage=lastTriggeredImage; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
DeploymentTriggerImageChangeParamsFluentImpl that = (DeploymentTriggerImageChangeParamsFluentImpl) o;
if (automatic != null ? !automatic.equals(that.automatic) :that.automatic != null) return false;
if (containerNames != null ? !containerNames.equals(that.containerNames) :that.containerNames != null) return false;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (lastTriggeredImage != null ? !lastTriggeredImage.equals(that.lastTriggeredImage) :that.lastTriggeredImage != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FromNestedImpl<N> extends ObjectReferenceFluentImpl<FromNested<N>> implements FromNested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
             FromNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) DeploymentTriggerImageChangeParamsFluentImpl.this.withFrom(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.48-sources.jar: io/fabric8/openshift/api/model/DeploymentTriggerImageChangeParamsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;

public class DeploymentTriggerImageChangeParamsFluentImpl<T extends DeploymentTriggerImageChangeParamsFluent<T>> extends BaseFluent<T> implements DeploymentTriggerImageChangeParamsFluent<T>{

     Boolean automatic;     List<String> containerNames = new ArrayList();     VisitableBuilder<ObjectReference, ?> from;     String lastTriggeredImage;     Map<String, Object> additionalProperties = new HashMap();
public DeploymentTriggerImageChangeParamsFluentImpl(){
    
}
public DeploymentTriggerImageChangeParamsFluentImpl( DeploymentTriggerImageChangeParams instance ){
    this.withAutomatic(instance.getAutomatic()); this.withContainerNames(instance.getContainerNames()); this.withFrom(instance.getFrom()); this.withLastTriggeredImage(instance.getLastTriggeredImage()); 
}

    public Boolean isAutomatic(){
    return this.automatic;
    }
    public T withAutomatic( Boolean automatic){
    this.automatic=automatic; return (T) this;
    }
    public T addToContainerNames( String ...items){
    for (String item : items) {this.containerNames.add(item);} return (T)this;
    }
    public T removeFromContainerNames( String ...items){
    for (String item : items) {this.containerNames.remove(item);} return (T)this;
    }
    public List<String> getContainerNames(){
    return this.containerNames;
    }
    public T withContainerNames( List<String> containerNames){
    this.containerNames.clear();if (containerNames != null) {for (String item : containerNames){this.addToContainerNames(item);}} return (T) this;
    }
    public T withContainerNames( String ...containerNames){
    this.containerNames.clear(); if (containerNames != null) {for (String item :containerNames){ this.addToContainerNames(item);}} return (T) this;
    }
    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNestedImpl<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNestedImpl<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public String getLastTriggeredImage(){
    return this.lastTriggeredImage;
    }
    public T withLastTriggeredImage( String lastTriggeredImage){
    this.lastTriggeredImage=lastTriggeredImage; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
DeploymentTriggerImageChangeParamsFluentImpl that = (DeploymentTriggerImageChangeParamsFluentImpl) o;
if (automatic != null ? !automatic.equals(that.automatic) :that.automatic != null) return false;
if (containerNames != null ? !containerNames.equals(that.containerNames) :that.containerNames != null) return false;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (lastTriggeredImage != null ? !lastTriggeredImage.equals(that.lastTriggeredImage) :that.lastTriggeredImage != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FromNestedImpl<N> extends ObjectReferenceFluentImpl<FromNested<N>> implements FromNested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNestedImpl (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             FromNestedImpl ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) DeploymentTriggerImageChangeParamsFluentImpl.this.withFrom(builder.build());
        }
    
}


}
